<?php
/*
Plugin Name: HF solar widget
Version: 0.2
Plugin URI: https://ns6t.net/word/?page_id=88
Description: Provide a simple widget display to show HF propagation and solar-terrestrial data, based on examples here on <a href="https://www.hamqsl.com/solar.html">www.hamqsl.com</a>.
Author: Tom Epperly
Author URI: https://ns6t.net/
License: GPL2
 */

  /*  Copyright 2010,2023 Tom Epperly  (email : tepperly@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */

class HFSolar_Widget extends WP_Widget {
   public function __construct() {
     parent::__construct( 'hfsolar_widget', // base ID
        esc_html__('HF Solar-Terrestrial Data', 'text_domain'), // name
	array( 'description' => esc_html__('A widget to display solar-terrestrial data on your website!', 'text_domain'), )
	);
   }

   public function widget( $args, $instance) {
     echo $args['before_widget'];
     echo $args['before_title'] . 'Solar-Terrestrial Data' . $args['after_title'];
 ?>
     <p style="text-align: center;">
       <a href="https://www.hamqsl.com/solar.html" title="Click to add Solar-Terrestrial Data to your website!"><img src="<?php
     switch($instance['hfsolarstyle']) {
     case "vertical-sun":
        echo "https://www.hamqsl.com/solarpic.php";
        break;
     case "vertical-hfvhf":
        echo "https://www.hamqsl.com/solarvhf.php";
        break;
     case "vertical-noband":
        echo "https://www.hamqsl.com/solar.php";
        break;
     case "vertical-bands":
        echo "https://www.hamqsl.com/solar100sc.php";
        break;
     case "vertical-calcs":
        echo "https://www.hamqsl.com/solar2.php";
        break;
     case "vertical-n0nbh":
        echo "https://www.hamqsl.com/solarn0nbh.php";
        break;
     case "vertical-small":
        echo "https://www.hamqsl.com/solarsmall.php";
        break;
     case "horiz-tiny":
        echo "https://www.hamqsl.com/solarbrief.php";
        break;
     case "horiz-sun1":
        echo "https://www.hamqsl.com/solarpich.php";
        break;
     case "horiz-sun2":
        echo "https://www.hamqsl.com/solar101pic.php";
        break;
     case "horiz-hfvhf":
        echo "https://www.hamqsl.com/solar101vhf.php";
        break;
     case "horiz-calcs":
        echo "https://www.hamqsl.com/solar101sc.php";
        break;
     default:
        echo "https://www.hamqsl.com/solar100sc.php";
        break;
    }
?>"></a>
     </p>
<?php
     echo $args['after_widget'];
   }

   public function form( $instance ) {
      $selectedoption = ! empty( $instance['hfsolarstyle'] ) ? $instance['hfsolarstyle'] : 'vertical-bands';
      $conlist=array(12);
      $conlist[0] = "vertical-sun";
      $conlist[1] = "vertical-hfvhf";
      $conlist[2] = "vertical-noband";
      $conlist[3] = "vertical-bands";
      $conlist[4] = "vertical-calcs";
      $conlist[5] = "vertical-n0nbh";
      $conlist[6] = "vertical-small";
      $conlist[7] = "horiz-tiny";
      $conlist[8] = "horiz-sun1";
      $conlist[9] = "horiz-sun2";
      $conlist[10] = "horiz-hfvhf";
      $conlist[11] = "horiz-calcs";
      $text["vertical-sun"] =  "155x319 with Sun";
      $text["vertical-hfvhf"] = "155x340 with HF/VHF";
      $text["vertical-noband"] = "155x221 with no bands";
      $text["vertical-bands"] =  "155x233 with bands";
      $text["vertical-calcs"] = "155x311 with band calcs";
      $text["vertical-n0nbh"] = "155x530 with HF/VHS and Sun";
      $text["vertical-small"] = "155x160 small";
      $text["horiz-tiny"] = "155x76 tiny";
      $text["horiz-sun1"] = "290x168 with sun";
      $text["horiz-sun2"] = "410x125 with sun and bands";
      $text["horiz-hfvhf"] = "460x125 with HF/VHF";
      $text["horiz-calcs"] =  "460x125 with band calcs";
?>
      <p>
        <label for="<?php echo esc_attr( $this->get_field_id( 'hfsolarstyle' ) ); ?>"><?php esc_attr_e(
	  'HF Solar-Terrestrial Data Style', 'text_domain'); ?></label>
	  <select id="<?php echo esc_attr( $this->get_field_id( 'hfsolarstyle' ) ); ?>" name="<?php
          echo esc_attr( $this->get_field_name( 'hfsolarstyle' ) ); ?>">
<?php
       for ($ind=0;$ind<9;++$ind) { 
?>
      <option <?php
         if ($conlist[$ind] == $selectedoption) {
	    ?> selected="true" <?php
	 } 
	 ?> value="<?php
	 echo esc_attr($conlist[$ind]);
	 ?>"><?php
            esc_attr_e($text[$conlist[$ind]], 'text_domain');
	 ?></option>
<?php
    }
?>
	  </select>
<?php
   }

   public function update( $new_instance, $old_instance ) {
      $instance = array();
      $instance['hfsolarstyle'] = ( ! empty( $new_instance['hfsolarstyle'] ) ? sanitize_text_field($new_instance['hfsolarstyle'] ) : 'vertical-bands' );
      return $instance;
   }
}

function register_hfsolar_widget() {
   register_widget( 'HFSolar_Widget' );
}
add_action( 'widgets_init', 'register_hfsolar_widget' );
?>
